@@ -1,4 +1,4 @@
-/* $Id$ */
+/* $Id: mountlist.c,v 1.8.4.1 2002/01/14 00:56:50 baddog Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -47,8 +47,8 @@ main (int argc, char *argv [])
 	char buffer [BUFSIZ];
 
 	setlocale (LC_ALL, "");
-	bindtextdomain (PACKAGE, GTOPLOCALEDIR);
-	textdomain (PACKAGE);
+	bindtextdomain (GETTEXT_PACKAGE, GTOPLOCALEDIR);
+	textdomain (GETTEXT_PACKAGE);
 	
 	glibtop_init_r (&glibtop_global_server, 0, GLIBTOP_INIT_NO_OPEN);
 
@@ -96,7 +96,7 @@ main (int argc, char *argv [])
 		glibtop_get_fsusage (&fsusage,
 				     mount_entries [index].mountdir);
 
-		printf ("Usage: %-16s %9llu %9llu %9llu %9llu %9llu\n",
+		printf ("Usage: %-16s %9Lu %9Lu %9Lu %9Lu %9Lu\n",
 			mount_entries [index].mountdir,
 			fsusage.blocks, fsusage.bfree,
 			fsusage.bavail, fsusage.files,
