@@ -1,6 +1,4 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
-
-/* $Id$ */
+/* $Id: mountlist.c,v 1.3 1999/02/23 11:45:24 martin Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -21,14 +19,30 @@
    along with LibGTop; see the file COPYING. If not, write to the
    Free Software Foundation, Inc., 59 Temple Place - Suite 330,
    Boston, MA 02111-1307, USA.
- */
+*/
 
 #include <glibtop/mountlist.h>
 
-const char *glibtop_names_mountlist[] = { };
+const char *glibtop_names_mountlist [GLIBTOP_MAX_MOUNTLIST] =
+{
+	"number", "total", "size"
+};
 
-const unsigned glibtop_types_mountlist[] = { };
+const unsigned glibtop_types_mountlist [GLIBTOP_MAX_MOUNTLIST] =
+{
+	GLIBTOP_TYPE_ULONG, GLIBTOP_TYPE_ULONG, GLIBTOP_TYPE_ULONG
+};
 
-const char *glibtop_labels_mountlist[] = { };
+const char *glibtop_labels_mountlist [GLIBTOP_MAX_MOUNTLIST] =
+{
+	N_("Number of list elements"),
+	N_("Total size of list"),
+	N_("Size of a single list element")
+};
 
-const char *glibtop_descriptions_mountlist[] = { };
+const char *glibtop_descriptions_mountlist [GLIBTOP_MAX_MOUNTLIST] =
+{
+	N_("Number of list elements"),
+	N_("Total size of list"),
+	N_("Size of a single list element")
+};
